==> wheezy.routing-0.1.168.tar.gz: wheezy.routing-0.1.168/README.md <==
# wheezy.routing

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.routing.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.routing)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.routing/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.routing?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezyrouting/badge/?version=latest)](https://wheezyrouting.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.routing.svg)](https://badge.fury.io/py/wheezy.routing)

[wheezy.routing](https://pypi.org/project/wheezy.routing/) is a
[python](https://www.python.org) package written in pure Python code. It
is a simple mapping between URL patterns (as plain simple strings, curly
expressions or regular expressions) to a handler that can be anything
you like (there is no limitation or prescription what handler is or
could be).

The mapping can include other mappings and constructed dynamically.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.routing),
  [examples](https://github.com/akornatskyy/wheezy.routing/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.routing/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.routing)
- [documentation](https://wheezyrouting.readthedocs.io/en/latest/)

## Install

[wheezy.routing](https://pypi.org/project/wheezy.routing) requires
[python](https://www.python.org) version 2.4 to 2.7 or 3.2+. It is
independent of operating system. You can install it from
[pypi](https://pypi.org/project/wheezy.routing/):

```sh
pip install -U wheezy.routing
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.routing).

==> wheezy.routing-3.0.1.tar.gz: wheezy.routing-3.0.1/README.md <==
# wheezy.routing

[![Build Status](https://travis-ci.org/akornatskyy/wheezy.routing.svg?branch=master)](https://travis-ci.org/akornatskyy/wheezy.routing)
[![Coverage Status](https://coveralls.io/repos/github/akornatskyy/wheezy.routing/badge.svg?branch=master)](https://coveralls.io/github/akornatskyy/wheezy.routing?branch=master)
[![Documentation Status](https://readthedocs.org/projects/wheezyrouting/badge/?version=latest)](https://wheezyrouting.readthedocs.io/en/latest/?badge=latest)
[![pypi version](https://badge.fury.io/py/wheezy.routing.svg)](https://badge.fury.io/py/wheezy.routing)

[wheezy.routing](https://pypi.org/project/wheezy.routing/) is a
[python](https://www.python.org) package written in pure Python code. It
is a simple mapping between URL patterns (as plain simple strings, curly
expressions or regular expressions) to a handler that can be anything
you like (there is no limitation or prescription what handler is or
could be).

The mapping can include other mappings and constructed dynamically.

It is optimized for performance, well tested and documented.

Resources:

- [source code](https://github.com/akornatskyy/wheezy.routing),
  [examples](https://github.com/akornatskyy/wheezy.routing/tree/master/demos)
  and [issues](https://github.com/akornatskyy/wheezy.routing/issues)
  tracker are available on
  [github](https://github.com/akornatskyy/wheezy.routing)
- [documentation](https://wheezyrouting.readthedocs.io/en/latest/)

## Install

[wheezy.routing](https://pypi.org/project/wheezy.routing) requires
[python](https://www.python.org) version 3.6+. It is independent of operating
system. You can install it from
[pypi](https://pypi.org/project/wheezy.routing/):

```sh
pip install -U wheezy.routing
```

If you run into any issue or have comments, go ahead and add on
[github](https://github.com/akornatskyy/wheezy.routing).
